::: py_outfit.PyOutfit

Physical and astronomical constants exposed by Outfit.

These values are provided in SI units or astronomical conventions

::: py_outfit
    options:
      show_root_toc_entry: true
      show_root_heading: true
      show_category_heading: true
      show_source: true
      members_order: source
      filters:
        - "!^_"
